pub struct CommentSettings { /* private fields */ }
Settings for StripComments

The default is for all comment types to be enabled.

Implementations

Enable all comment Styles

Only allow line comments starting with #

Only allow “c-style” comments.

Specifically, line comments beginning with // and block comment like /* ... */.

Create a new StripComments for input, using these settings.

Transform input into a Read that strips out comments. The types of comments to support are determined by the configuration of self.

Examples
use json_comments::CommentSettings;
use std::io::Read;

let input = r#"{
// c line comment
"a": "b"
/** multi line
comment
*/ }"#;

let mut stripped = String::new();
CommentSettings::c_style().strip_comments(input.as_bytes()).read_to_string(&mut stripped).unwrap();

assert_eq!(stripped, "{
                 \n\"a\": \"b\"
                          }");
use json_comments::CommentSettings;
use std::io::Read;

let input = r#"{
# shell line comment
"a": "b"
}"#;

let mut stripped = String::new();
CommentSettings::hash_only().strip_comments(input.as_bytes()).read_to_string(&mut stripped).unwrap();

assert_eq!(stripped, "{
                    \n\"a\": \"b\"\n}");